==> qtmclock_config0.0.1.tar.gz: qtmclock_config0.0.1/qtmclock_config_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec>ISO-8859-5</defaultcodec>
<context>
    <name>ReleaseDialog</name>
    <message>
        <location filename="ReleaseDialogForm.ui" line="13"/>
        <source>Theme Config: Release</source>
        <translation>Theme Config: Release</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="26"/>
        <source>Theme File</source>
        <translation>出力ファイル名</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="62"/>
        <source>RRDA Key</source>
        <translation type="unfinished">RRDA キー</translation>
    </message>
</context>
<context>
    <name>ThemeConfigWindow</name>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="18"/>
        <source>Theme Config</source>
        <translation>Theme Config</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="183"/>
        <source>long hand</source>
        <translation>長針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="160"/>
        <source>base</source>
        <translation>ベース</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="175"/>
        <source>short hand</source>
        <translation>短針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="191"/>
        <source>second hand</source>
        <translation>秒針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="200"/>
        <source>digital character</source>
        <translation>デジタル文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="355"/>
        <source>toolbar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="207"/>
        <source>hour</source>
        <translation>時</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="231"/>
        <source>minute</source>
        <translation>分</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="247"/>
        <source>second</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="263"/>
        <source>AM/PM</source>
        <translation>AM/PM</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="223"/>
        <source>colon</source>
        <translation>コロン</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="150"/>
        <source>Node</source>
        <translation>項目</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="155"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="369"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="676"/>
        <source>Create a new config file.</source>
        <translation>設定ファイルの新規作成.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="377"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="680"/>
        <source>Open an exist config file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="385"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="684"/>
        <source>Save the config file to disk.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="101"/>
        <source>hands&apos;s center are samve.</source>
        <translation>長針、短針、秒針の中心を揃える.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="92"/>
        <source>Drawing Options</source>
        <translation>配置オプション</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="168"/>
        <source>analog parts</source>
        <translation>アナログ部品</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="40"/>
        <source>Play / Stop</source>
        <translation>再生 / 停止</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="57"/>
        <source>Pause / Resume</source>
        <translation>一時停止 / 再開</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="308"/>
        <source>File (&amp;F)</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="321"/>
        <source>Edit (&amp;E)</source>
        <translation>編集 (&amp;E)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="327"/>
        <source>Help (&amp;H)</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="675"/>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="679"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="683"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="390"/>
        <source>Release (&amp;R)</source>
        <translation>リリース (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="395"/>
        <source>Exit (&amp;Q)</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="398"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="403"/>
        <source>Save as</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="408"/>
        <source>Preview (&amp;R)</source>
        <translation>プレビュー (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="411"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="416"/>
        <source>About (&amp;A)</source>
        <translation>このアプリケーションについて (&amp;A)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="214"/>
        <source>h2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="238"/>
        <source>m2</source>
        <translation>位置 (1 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="254"/>
        <source>s2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="111"/>
        <source>blink digital colon.</source>
        <translation>デジタル文字のコロン表示を点滅させる.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="131"/>
        <source>show digital second.</source>
        <translation>デジタル文字の秒を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="750"/>
        <source>Open archive list file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="783"/>
        <source>archive list (*.txt)</source>
        <translation>設定ファイル (*.txt)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="782"/>
        <source>Save archive list file.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="366"/>
        <source>New (&amp;N)</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="374"/>
        <source>Open (&amp;O)</source>
        <translation>開く (&amp;O)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="382"/>
        <source>Save (&amp;S)</source>
        <translation>保存 (&amp;S)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="277"/>
        <source>Parts image</source>
        <translation>部品画像の更新</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="287"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="121"/>
        <source>show analog second.</source>
        <translation>秒針を表示する.</translation>
    </message>
</context>
</TS>

==> qtmclock_config0.0.3.tar.gz: qtmclock_config0.0.3/qtmclock_config_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec>ISO-8859-5</defaultcodec>
<context>
    <name>ReleaseDialog</name>
    <message>
        <location filename="ReleaseDialogForm.ui" line="13"/>
        <source>Theme Config: Release</source>
        <translation>Theme Config: Release</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="26"/>
        <source>Theme File</source>
        <translation>出力ファイル名</translation>
    </message>
    <message>
        <location filename="ReleaseDialogForm.ui" line="62"/>
        <source>RRDA Key</source>
        <translation>RRDA キー</translation>
    </message>
</context>
<context>
    <name>ThemeConfigWindow</name>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="18"/>
        <source>Theme Config</source>
        <translation>Theme Config</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="183"/>
        <source>long hand</source>
        <translation>長針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="160"/>
        <source>base</source>
        <translation>ベース</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="175"/>
        <source>short hand</source>
        <translation>短針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="191"/>
        <source>second hand</source>
        <translation>秒針</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="200"/>
        <source>digital character</source>
        <translation>デジタル文字</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="355"/>
        <source>toolbar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="207"/>
        <source>hour</source>
        <translation>時</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="231"/>
        <source>minute</source>
        <translation>分</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="247"/>
        <source>second</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="263"/>
        <source>AM/PM</source>
        <translation>AM/PM</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="223"/>
        <source>colon</source>
        <translation>コロン</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="150"/>
        <source>Node</source>
        <translation>項目</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="155"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="369"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="719"/>
        <source>Create a new config file.</source>
        <translation>設定ファイルの新規作成.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="377"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="723"/>
        <source>Open an exist config file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="385"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="727"/>
        <source>Save the config file to disk.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="101"/>
        <source>hands&apos;s center are samve.</source>
        <translation>長針、短針、秒針の中心を揃える.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="92"/>
        <source>Drawing Options</source>
        <translation>配置オプション</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="168"/>
        <source>analog parts</source>
        <translation>アナログ部品</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="40"/>
        <source>Play / Stop</source>
        <translation>再生 / 停止</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="57"/>
        <source>Pause / Resume</source>
        <translation>一時停止 / 再開</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="308"/>
        <source>File (&amp;F)</source>
        <translation>ファイル (&amp;F)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="321"/>
        <source>Edit (&amp;E)</source>
        <translation>編集 (&amp;E)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="327"/>
        <source>Help (&amp;H)</source>
        <translation>ヘルプ (&amp;H)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="718"/>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="722"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="726"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="390"/>
        <source>Release (&amp;R)</source>
        <translation>リリース (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="395"/>
        <source>Exit (&amp;Q)</source>
        <translation>終了 (&amp;Q)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="398"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="403"/>
        <source>Save as</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="408"/>
        <source>Preview (&amp;R)</source>
        <translation>プレビュー (&amp;R)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="411"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="416"/>
        <source>About (&amp;A)</source>
        <translation>このアプリケーションについて (&amp;A)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="214"/>
        <source>h2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="238"/>
        <source>m2</source>
        <translation>位置 (1 の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="254"/>
        <source>s2</source>
        <translation>位置 (1の位)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="111"/>
        <source>blink digital colon.</source>
        <translation>デジタル文字のコロン表示を点滅させる.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="131"/>
        <source>show digital second.</source>
        <translation>デジタル文字の秒を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="794"/>
        <source>Open archive list file.</source>
        <translation>設定ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="827"/>
        <source>archive list (*.txt)</source>
        <translation>設定ファイル (*.txt)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="826"/>
        <source>Save archive list file.</source>
        <translation>設定ファイルの保存.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="366"/>
        <source>New (&amp;N)</source>
        <translation>新規作成 (&amp;N)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="374"/>
        <source>Open (&amp;O)</source>
        <translation>開く (&amp;O)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="382"/>
        <source>Save (&amp;S)</source>
        <translation>保存 (&amp;S)</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="277"/>
        <source>Parts image</source>
        <translation>部品画像の更新</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="287"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindowForm.ui" line="121"/>
        <source>show analog second.</source>
        <translation>秒針を表示する.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="992"/>
        <source>Open parts file.</source>
        <translation>部品ファイルを開く.</translation>
    </message>
    <message>
        <location filename="ThemeConfigWindow.cpp" line="993"/>
        <source>parts file (*.png)</source>
        <translation>部品ファイル (*.png)</translation>
    </message>
</context>
</TS>
